@@ -1,5 +1,5 @@
 # Copyright (c) 2020 6WIND S.A.
-# SPDX-License-Identifier: BSD-3-Clause
+# SPDX-License-Identifier: MIT
 
 import logging
 
@@ -178,7 +178,7 @@ class DNode:
         node_p[0] = self._node
         ret = lib.lyd_validate(node_p, flags, ffi.NULL)
         if ret != 0:
-            self.context.error('validation failed')
+            raise self.context.error('validation failed')
 
     def merge(self, source, destruct=False, no_siblings=False, explicit=False):
         flags = parser_flags(destruct=destruct, no_siblings=no_siblings,
@@ -525,8 +525,25 @@ def dict_to_dnode(dic, module, parent=None, rpc=False, rpcreply=False,
         schema_cache[cache_key] = (snode, module)
         return snode, module
 
+    keys_cache = {}
+
+    def _dic_keys(_dic, _schema):
+        if isinstance(_schema, SList):
+            # list keys must be first and in the order specified in the schema
+            list_keys = keys_cache.get(_schema._node, None)
+            if list_keys is None:
+                list_keys = tuple(k.name() for k in _schema.keys())
+                keys_cache[_schema._node] = list_keys
+            keys = []
+            for k in list_keys:
+                if k in _dic:
+                    keys.append(k)
+            keys.extend(_dic.keys() - list_keys)
+            return keys
+        return _dic.keys()
+
     def _to_dnode(_dic, _schema, _parent=ffi.NULL, in_rpc_output=False):
-        for key, value in _dic.items():
+        for key in _dic_keys(_dic, _schema):
             if ':' in key:
                 prefix, name = name.split(':')
             else:
@@ -545,6 +562,8 @@ def dict_to_dnode(dic, module, parent=None, rpc=False, rpcreply=False,
                 LOG.warning('%s: skipping unknown element %r', path, key)
                 continue
 
+            value = _dic[key]
+
             if isinstance(s, SLeaf):
                 _create_leaf(_parent, module, name, value, in_rpc_output)
 
